@@ -7,7 +7,7 @@ use Net::Fastly::Client;
 use Net::Fastly::Invoice;
 use Net::Fastly::Settings;
 
-our $VERSION = "0.95";
+our $VERSION = "0.96";
 
 
 BEGIN {
@@ -31,7 +31,7 @@ BEGIN {
         my $glob = "${method}_${name}";
         $glob .= "s" if $method eq 'list';
         # don't create this if it's a list and something isn't listable ...
-        next if $method eq 'list' && !defined $class->_list_path;
+        next if $method eq 'list' && $class->_skip_list;
         # or if it already exists (i.e it's been overidden)
         next if defined *$glob;
         *$glob = eval "$code";
@@ -241,6 +241,14 @@ Create new objects.
 
 =head2 get_healthcheck <service id> <version number> <name>
 
+=head2 get_invoice [<year> <month>]
+
+Return a Net::Fastly::Invoice objects representing an invoice for all services.
+
+If a year and month are passed in returns the invoice for that whole month. 
+
+Otherwise it returns the invoices for the current month to date.
+
 =head2 get_match <service id> <version number> <name>
 
 =head2 get_origin <service id> <version number> <name>
@@ -359,14 +367,6 @@ Note - you can also do
 
 Get a list of all objects
 
-=head2 list_invoices [<year> <month>]
-
-Return an array of Net::Fastly::Invoice objects representing invoices for all services.
-
-If a year and month are passed in returns the invoices for that whole month. 
-
-Otherwise it returns the invoices for the current month so far.
-
 =head2 search_services <param[s]>
 
 Search all the services that the current customer has.
