@@ -4,7 +4,7 @@ use strict;
 use base qw(Net::Fastly::BelongsToServiceAndVersion);
 
 Net::Fastly::Backend->mk_accessors(qw(service_id name address ipv4 ipv6 hostname use_ssl client_cert port
-                                 connect_timeout first_byte_timeout between_bytes_timeout error_threshold max_conn weight comment));             
+                                 connect_timeout first_byte_timeout between_bytes_timeout error_threshold max_conn weight comment healthcheck));             
 
 =head1 NAME
 
@@ -74,6 +74,10 @@ the maximum number of connections to this backend (default 20)
 
 the weight assigned to this backend (default 100)
 
+=head2 healthcheck
+
+the name of a healthcheck to associate with this backend. See the Healthcheck object
+
 =cut
 
 1;
\ No newline at end of file
